/*
 * Copyright 2005-2006 The Portal Application Laboratory Team.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package jp.sf.pal.blog.model;

import java.util.Date;

import javax.faces.context.FacesContext;

import jp.sf.pal.blog.BlogConstants;

import org.apache.commons.lang.StringUtils;

import com.marevol.utils.faces.util.DateFormatUtil;

/**
 * BlogComment generated by hbm2java
 */
public class BlogComment implements java.io.Serializable
{

    // Fields    

    /**
     * 
     */
    private static final long serialVersionUID = 562524292609035239L;

    public static final String ID = "id";

    public static final String NAME = "name";

    public static final String EMAIL = "email";

    public static final String URL = "url";

    public static final String MESSAGE = "message";

    public static final String CREATEDTIME = "createdtime";

    private Long id;

    private BlogMessage blogMessage;

    private String name;

    private String email;

    private String url;

    private String message;

    private Date createdtime;

    // Constructors

    /** default constructor */
    public BlogComment()
    {
    }

    /** constructor with id */
    public BlogComment(Long id)
    {
        this.id = id;
    }

    // Property accessors

    /**
     * 
     */
    public Long getId()
    {
        return this.id;
    }

    public void setId(Long id)
    {
        this.id = id;
    }

    /**
     * 
     */
    public BlogMessage getBlogMessage()
    {
        return this.blogMessage;
    }

    public void setBlogMessage(BlogMessage blogMessage)
    {
        this.blogMessage = blogMessage;
    }

    /**
     * 
     */
    public String getName()
    {
        return this.name;
    }

    public void setName(String name)
    {
        this.name = name;
    }

    /**
     * 
     */
    public String getEmail()
    {
        return this.email;
    }

    public void setEmail(String email)
    {
        this.email = email;
    }

    /**
     * 
     */
    public String getUrl()
    {
        if (url != null
                && (url.startsWith("http://") || url.startsWith("https://")))
        {
            return this.url;
        }
        return "";
    }

    public void setUrl(String url)
    {
        this.url = url;
    }

    /**
     * 
     */
    public String getMessage()
    {
        return this.message;
    }

    public void setMessage(String message)
    {
        this.message = message;
    }

    /**
     * 
     */
    public Date getCreatedtime()
    {
        return this.createdtime;
    }

    public void setCreatedtime(Date createdtime)
    {
        this.createdtime = createdtime;
    }

    public Boolean getDeleteEnabled()
    {
        String user = FacesContext.getCurrentInstance().getExternalContext()
                .getRemoteUser();
        if (user == null)
        {
            return Boolean.FALSE;
        }

        if (user.equals(getBlogMessage().getOwner()))
        {
            return Boolean.TRUE;
        }
        return Boolean.FALSE;

    }

    public String getFormattedCreatedtime()
    {
        return DateFormatUtil.getMediumFormattedDateTime(getCreatedtime());
    }

    public String getAbbreviatedMessage()
    {
        return getAbbreviatedMessage(BlogConstants.DEFAULT_TITLE_MAX_LENGTH);
    }

    public String getAbbreviatedMessage(int maxLength)
    {
        return StringUtils.abbreviate(getMessage(), maxLength);
    }

    public void setAbbreviatedMessage(String msg)
    {
        setMessage(msg);
    }

    /**
     * @return Returns the emptyComment.
     */
    public boolean isEmptyMessage()
    {
        return StringUtils.isEmpty(getMessage());
    }

    /**
     * @param emptyComment The emptyComment to set.
     */
    public void setEmptyMessage(boolean emptyMessage)
    {
    }

    /**
     * @return Returns the emptyEmail.
     */
    public boolean isEmptyEmail()
    {
        return StringUtils.isEmpty(getEmail());
    }

    /**
     * @param emptyEmail The emptyEmail to set.
     */
    public void setEmptyEmail(boolean emptyEmail)
    {
    }

    /**
     * @return Returns the emptyUrl.
     */
    public boolean isEmptyUrl()
    {
        return StringUtils.isEmpty(getUrl());
    }

    /**
     * @param emptyUrl The emptyUrl to set.
     */
    public void setEmptyUrl(boolean emptyUrl)
    {
    }
}
